==> ReleaseV1.1.0.tar.gz: winginterfacelibrary/src/Interface/ILoginService.cs <==
﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.User;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 登录注册服务
    /// </summary>
    /// <value>个人信息接口</value>
    /// <example>客户端API</example>
    [System.ComponentModel.Description("WingUserModule")]
    public interface ILoginService
    {
        /// <summary>
        /// 通用登录
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>Session信息</returns>
        /// <errorCodes>VerificationCodeIllegality,UserNotRegistered,IncorrectPasswordFormat,AccountIsEmpty,AccountLengthError,SMSVerifyCodeIsEmpty,SMSVerifyCodeExpired,SMSVerifyCodeIllegality,ExceptionError,EmailVerifyCodeExpired,PhoneIncorrect,EmailIncorrect,EmailEmpty,EmailUserNotExisted,PasswordEmpty,PasswordError,IncorrectAccount,PhoneEmpty,PhoneUserNotExisted</errorCodes>
        Task<UserTokenDTO> CommonLoginAsync(CommonLoginRequest request);

        Task<int> CheckLoginTypeAsync(CheckLoginTypeRequest request);

        /// <summary>
        /// 通用注册
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNameRegistered,PhoneRegistered,EmailRegistered,NewPasswordEmpty,AccountIsEmpty,AccountLengthError,PhoneIncorrect,VerificationCodeIncorrect,EmailIncorrect,EmailVerifyCodeExpired,VerificationCodeIllegality</errorCodes>
        Task<bool> CommonSignUpAsync(CommonSignUpRequest request);

        Task<bool> CheckSMSVerificationCodeAsync(CheckSMSVerificationCodeRequest request);

        /// <summary>
        /// 发送短信验证码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> SendSMSVerificationCodeAsync(SendSMSVerificationCodeRequest request);

        /// <summary>
        /// 发送邮箱验证码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>EmailIncorrect</errorCodes>
        Task<bool> SendEmailVerificationCodeAsync(SendEmailVerificationCodeRequest request);

        /// <summary>
        /// 检查邮箱验证码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>EmailIncorrect,EmailVerifyCodeExpired,VerificationCodeIllegality</errorCodes>
        Task<bool> CheckEmailVerificationCodeAsync(CheckEmailVerificationCodeRequest request);

        /// <summary>
        /// 根据手机找回密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>VerificationCodeIllegality,UserNotRegistered</errorCodes>
        Task<bool> RetrievePasswordByPhoneAsync(RetrievePasswordByPhoneRequest request);

        /// <summary>
        /// 根据邮箱找回密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>EmailIncorrect,VerificationCodeIllegality,UserNotRegistered</errorCodes>
        Task<bool> RetrievePasswordByEmailAsync(RetrievePasswordByEmailRequest request);

        /// <summary>
        /// 验证账户名是否可用
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否可用</returns>
        /// <value>true</value>
        Task<bool> VerifyAccountAsync(VerifyAccountRequest request);

        /// <summary>
        /// 修改密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNotExisted,PhoneIllegality,VerificationCodeIllegality,EmailIllegality,UserNameIllegality,PasswordError,UserNotRegistered,NewPasswordEmpty</errorCodes>
        Task<bool> ModifyPasswordAsync(ModifyPasswordRequest request);
    }
}

==> ReleaseV1.1.3.tar.gz: winginterfacelibrary/src/Interface/ILoginService.cs <==
﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 登录注册服务
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>个人信息接口</docSecondDirectory>
    public interface ILoginService
    {
        /// <summary>
        /// 通用登录
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>Session信息</returns>
        /// <errorCodes>VerificationCodeIllegality,UserNotRegistered,IncorrectPasswordFormat,AccountIsEmpty,AccountLengthError,SMSVerifyCodeIsEmpty,SMSVerifyCodeExpired,SMSVerifyCodeIllegality,ExceptionError,EmailVerifyCodeExpired,PhoneIncorrect,EmailIncorrect,EmailEmpty,EmailUserNotExisted,PasswordEmpty,PasswordError,IncorrectAccount,PhoneEmpty,PhoneUserNotExisted,AccountIsLocked</errorCodes>
        Task<LoginResult> CommonLoginAsync(CommonLoginRequest request);

        Task<int> CheckLoginTypeAsync(CheckLoginTypeRequest request);

        /// <summary>
        /// 通用注册
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNameRegistered,PhoneRegistered,EmailRegistered,NewPasswordEmpty,AccountIsEmpty,AccountLengthError,PhoneIncorrect,VerificationCodeIncorrect,EmailIncorrect,EmailVerifyCodeExpired,VerificationCodeIllegality</errorCodes>
        Task<bool> CommonSignUpAsync(CommonSignUpRequest request);

        Task<bool> CheckSMSVerificationCodeAsync(CheckSMSVerificationCodeRequest request);

        /// <summary>
        /// 发送短信验证码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> SendSMSVerificationCodeAsync(SendSMSVerificationCodeRequest request);

        /// <summary>
        /// 发送邮箱验证码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>EmailIncorrect</errorCodes>
        Task<bool> SendEmailVerificationCodeAsync(SendEmailVerificationCodeRequest request);

        /// <summary>
        /// 检查邮箱验证码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>EmailIncorrect,EmailVerifyCodeExpired,VerificationCodeIllegality</errorCodes>
        Task<bool> CheckEmailVerificationCodeAsync(CheckEmailVerificationCodeRequest request);

        /// <summary>
        /// 根据手机找回密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>VerificationCodeIllegality,UserNotRegistered</errorCodes>
        Task<bool> RetrievePasswordByPhoneAsync(RetrievePasswordByPhoneRequest request);

        /// <summary>
        /// 根据邮箱找回密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>EmailIncorrect,VerificationCodeIllegality,UserNotRegistered</errorCodes>
        Task<bool> RetrievePasswordByEmailAsync(RetrievePasswordByEmailRequest request);

        /// <summary>
        /// 验证账户名是否可用
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否可用</returns>
        /// <value>true</value>
        Task<bool> VerifyAccountAsync(VerifyAccountRequest request);

        /// <summary>
        /// 修改密码
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNotExisted,PhoneIllegality,VerificationCodeIllegality,EmailIllegality,UserNameIllegality,PasswordError,UserNotRegistered,NewPasswordEmpty</errorCodes>
        Task<bool> ModifyPasswordAsync(ModifyPasswordRequest request);

        /// <summary>
        /// 生成密码
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> GenerateNewPasswordAsync(GenerateNewPasswordRequest request);

        /// <summary>
        /// 退出登录
        /// </summary>
        /// <param name="request">登录token信息</param>
        /// <returns>是否成功</returns>
        Task<bool> LoginOutAsync(TokenRequest request);
    }
}
